@@ -2,48 +2,48 @@
 ## PLOTTING CHECKS
 ######################
 
-test_that("Coxph plot time column missing", {
-  a <- c(0, 1, 2, 3, 4, 5, 6)
-  b <- c(1, 2, 3, 4, 5, 6, 7)
-  c <- c(0, 1, 0, 0, 0, 1, 0)
-  d <- c(3, 4, 5, 6, 7, 8, 9)
-  df <- data.table("a" = a, "b" = b, "c" = c, "d" = d)
-  time1 <- "a_bad"
-  time2 <- "b"
-  event <- "c"
-  names <- c("d")
-  term_n <- c(0)
-  tform <- c("loglin")
-  keep_constant <- c(0)
-  a_n <- c(-0.1)
-  modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
-  plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = FALSE, "surv_curv" = FALSE, "studyid" = "a", "verbose" = 0)
-  if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
-  }
-})
-test_that("Coxph plot no events", {
-  a <- c(0, 1, 2, 3, 4, 5, 6)
-  b <- c(1, 2, 3, 4, 5, 6, 7)
-  c <- c(0, 0, 0, 0, 0, 0, 0)
-  d <- c(3, 4, 5, 6, 7, 8, 9)
-  df <- data.table("a" = a, "b" = b, "c" = c, "d" = d)
-  time1 <- "a"
-  time2 <- "b"
-  event <- "c"
-  names <- c("d")
-  term_n <- c(0)
-  tform <- c("loglin")
-  keep_constant <- c(0)
-  a_n <- c(-0.1)
-  modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
-  plot_options <- list("type" = c("surv", "run"), "martingale" = FALSE, "surv_curv" = FALSE, "studyid" = "a", "verbose" = 0)
-  if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
-  }
-})
+# test_that("Coxph plot time column missing", {
+#   a <- c(0, 1, 2, 3, 4, 5, 6)
+#   b <- c(1, 2, 3, 4, 5, 6, 7)
+#   c <- c(0, 1, 0, 0, 0, 1, 0)
+#   d <- c(3, 4, 5, 6, 7, 8, 9)
+#   df <- data.table("a" = a, "b" = b, "c" = c, "d" = d)
+#   time1 <- "a_bad"
+#   time2 <- "b"
+#   event <- "c"
+#   names <- c("d")
+#   term_n <- c(0)
+#   tform <- c("loglin")
+#   keep_constant <- c(0)
+#   a_n <- c(-0.1)
+#   modelform <- "M"
+#   control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
+#   plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = FALSE, "surv_curv" = FALSE, "studyid" = "a", "verbose" = 0)
+#   if (system.file(package = "ggplot2") != "") {
+#     expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+#   }
+# })
+# test_that("Coxph plot no events", {
+#   a <- c(0, 1, 2, 3, 4, 5, 6)
+#   b <- c(1, 2, 3, 4, 5, 6, 7)
+#   c <- c(0, 0, 0, 0, 0, 0, 0)
+#   d <- c(3, 4, 5, 6, 7, 8, 9)
+#   df <- data.table("a" = a, "b" = b, "c" = c, "d" = d)
+#   time1 <- "a"
+#   time2 <- "b"
+#   event <- "c"
+#   names <- c("d")
+#   term_n <- c(0)
+#   tform <- c("loglin")
+#   keep_constant <- c(0)
+#   a_n <- c(-0.1)
+#   modelform <- "M"
+#   control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
+#   plot_options <- list("type" = c("surv", "run"), "martingale" = FALSE, "surv_curv" = FALSE, "studyid" = "a", "verbose" = 0)
+#   if (system.file(package = "ggplot2") != "") {
+#     expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+#   }
+# })
 test_that("Coxph plot no type", {
   a <- c(0, 1, 2, 3, 4, 5, 6)
   b <- c(1, 2, 3, 4, 5, 6, 7)
@@ -59,10 +59,11 @@ test_that("Coxph plot no type", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   plot_options <- list("martingale" = FALSE, "surv_curv" = FALSE, "studyid" = "a", "verbose" = 0)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 test_that("Coxph plot strata col not in data", {
@@ -80,10 +81,11 @@ test_that("Coxph plot strata col not in data", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   plot_options <- list("type" = c("surv", "run"), "martingale" = FALSE, "surv_curv" = FALSE, "strat_haz" = TRUE, "strat_col" = "e", "studyid" = "a", "verbose" = 0)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 test_that("Coxph plot strata col not given", {
@@ -101,10 +103,11 @@ test_that("Coxph plot strata col not given", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   plot_options <- list("type" = c("surv", "run"), "martingale" = FALSE, "surv_curv" = FALSE, "strat_haz" = TRUE, "studyid" = "a", "verbose" = 0)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 test_that("Coxph plot martingale dose col not in data", {
@@ -122,10 +125,11 @@ test_that("Coxph plot martingale dose col not in data", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", "run"), "martingale" = TRUE, "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 test_that("Coxph plot martingale dose col not given", {
@@ -143,10 +147,11 @@ test_that("Coxph plot martingale dose col not given", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", "run"), "martingale" = TRUE, "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 test_that("Coxph plot Survival ID col not in data", {
@@ -164,10 +169,11 @@ test_that("Coxph plot Survival ID col not in data", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", "run"), "martingale" = FALSE, "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "f", "verbose" = 0, "km" = TRUE)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 test_that("Coxph plot Survival ID col not given", {
@@ -185,10 +191,11 @@ test_that("Coxph plot Survival ID col not given", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", "run"), "martingale" = FALSE, "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "verbose" = 0, "km" = TRUE)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
 })
 
@@ -196,7 +203,7 @@ test_that("Coxph risk too few unique values", {
   a <- c(0, 1, 2, 3, 4, 5, 6)
   b <- c(1, 2, 3, 4, 5, 6, 7)
   c <- c(1, 0, 1, 0, 1, 0, 0)
-  d <- c(3, 3, 3, 3, 3, 3, 3)
+  d <- c(3, 1, 3, 1, 2, 3, 1)
   df <- data.table("a" = a, "b" = b, "c" = c, "d" = d)
   time1 <- "a"
   time2 <- "b"
@@ -207,12 +214,16 @@ test_that("Coxph risk too few unique values", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("RISK", paste(tempfile(), "run", sep = "")), "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
+  d <- c(3, 3, 3, 3, 3, 3, 3)
+  df <- data.table("a" = a, "b" = b, "c" = c, "d" = d)
   options(warn = -1)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
+  options(warn = 0)
 })
 test_that("Coxph risk plotting above discrete step number limit", {
   a <- rep(c(0, 1, 2, 3, 4, 5, 6), 20)
@@ -230,10 +241,15 @@ test_that("Coxph risk plotting above discrete step number limit", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("RISK", paste(tempfile(), "run", sep = "")), "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(plot(e, df, type = c("RISK", paste(tempfile(), "run", sep = "")), studyid = "a", verbose = 0))
+    expect_error(plot(e, df, type = c("RISK", paste(tempfile(), "run", sep = "")), studyid = "a", bad = 0))
+    expect_error(plot(e, df, plot_options = c(0))$d)
+    expect_no_error(ep <- plot(e, df, plot_options)$d)
+    expect_equal(ep$y[100], 0.9756069, tolerance = 1e-4)
   }
 })
 
@@ -252,10 +268,12 @@ test_that("Coxph plot no error", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "surv_curv" = TRUE, "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox(tend = b, event = c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(ep <- plot(e, df, plot_options, verbose = 0)$standard)
+    expect_equal(ep$h, c(0.000000, 4.344177, 18.450904), tolerance = 1e-4)
   }
 })
 test_that("Coxph plot stratafied no error", {
@@ -274,10 +292,12 @@ test_that("Coxph plot stratafied no error", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "surv_curv" = TRUE, "strat_haz" = TRUE, "strat_col" = "e", "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox_Strata(a, b, c, e) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(ep <- plot(e, df, plot_options)$stratified_survival)
+    expect_equal(ep$surv[2], 0.5880531, tolerance = 1e-4)
   }
 })
 
@@ -296,10 +316,12 @@ test_that("Coxph risk no error", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("RISK", paste(tempfile(), "run", sep = "")), "studyid" = "a", "verbose" = 0)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(ep <- plot(e, df, plot_options)$d)
+    expect_equal(ep$y[7], 0.5488116, tolerance = 1e-4)
   }
 })
 
@@ -316,10 +338,12 @@ test_that("Coxph schoenfeld no error", {
   keep_constant <- c(0, 0)
   a_n <- c(0.01, -15)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("SCHOENFELD", paste(tempfile(), "run", sep = "")), "studyid" = "t0", "verbose" = 0)
+  e <- CoxRun(Cox(t0, t1, lung) ~ loglinear(a, b, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(ep <- plot(e, df, plot_options)$b)
+    expect_equal(ep$y[16], 9.999993e-01, tolerance = 1e-4)
   }
 })
 test_that("Coxph martingale no error", {
@@ -338,10 +362,12 @@ test_that("Coxph martingale no error", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "d", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "e", "verbose" = 0)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(ep <- plot(e, df, plot_options)$d)
+    expect_equal(ep$res_sum[2], -0.2262094, tolerance = 1e-4)
   }
 })
 test_that("Coxph martingale combinations", {
@@ -350,7 +376,8 @@ test_that("Coxph martingale combinations", {
   c <- c(0, 1, 0, 0, 0, 1, 0)
   d <- c(3, 4, 5, 6, 7, 8, 9)
   e <- c(1, 1, 2, 2, 3, 3, 3)
-  df <- data.table("a" = a, "b" = b, "c" = c, "d" = d, "e" = e)
+  f <- c(1, 2, 3, 4, 5, 6, 7)
+  df <- data.table("a" = a, "b" = b, "c" = c, "d" = d, "e" = e, "f" = f)
   time1 <- "a"
   time2 <- "b"
   event <- "c"
@@ -360,24 +387,30 @@ test_that("Coxph martingale combinations", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "d", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "Not_In", "verbose" = 0)
   keep_constant <- c(1)
   options(warn = -1)
   if (system.file(package = "ggplot2") != "") {
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
+    expect_error(plot(e, df, plot_options))
     names <- c("d", "CONST")
     term_n <- c(0, 0)
     tform <- c("loglin", "loglin")
     keep_constant <- c(0, 0)
     a_n <- c(-0.1, 0.1)
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
-    plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "Not_In", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "Not_In", "verbose" = 0)
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
-    plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "d", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "Not_In", "verbose" = 0)
+    plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "d", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "f", "verbose" = 0)
+    e <- CoxRun(Cox(a, b, c) ~ loglinear(d, CONST, 0), df, control = control, a_n = a_n)
+    expect_no_error(plot(e, df, plot_options))
+    plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "Not_In", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "f", "verbose" = 0)
+    e <- CoxRun(Cox(a, b, c) ~ loglinear(d, CONST, 0), df, control = control, a_n = a_n)
+    expect_error(plot(e, df, plot_options))
+    plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "martingale" = TRUE, "cov_cols" = "d", "surv_curv" = FALSE, "strat_haz" = FALSE, "smooth_haz" = FALSE, "studyid" = "f", "verbose" = 0)
+    e <- CoxRun(Cox(a, b, c) ~ loglinear(d, CONST, 0), df, control = control, a_n = a_n)
     df$c <- rep(0, nrow(df))
-    expect_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_error(plot(e, df, plot_options))
   }
+  options(warn = 0)
 })
 test_that("Coxph km no error", {
   a <- c(0, 1, 2, 3, 4, 5, 6)
@@ -394,9 +427,11 @@ test_that("Coxph km no error", {
   keep_constant <- c(0)
   a_n <- c(-0.1)
   modelform <- "M"
-  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 100.0, "verbose" = 0, "ties" = "breslow", "double_step" = 1)
+  control <- list("ncores" = 2, "lr" = 0.75, "maxiter" = -1, "halfmax" = 5, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "step_max" = 1.0, "change_all" = TRUE, "thres_step_max" = 100.0, "verbose" = 0, "ties" = "breslow")
   plot_options <- list("type" = c("surv", paste(tempfile(), "run", sep = "")), "surv_curv" = TRUE, "studyid" = "a", "verbose" = 0, "km" = TRUE)
+  e <- CoxRun(Cox(a, b, c) ~ loglinear(d, 0), df, control = control, a_n = a_n)
   if (system.file(package = "ggplot2") != "") {
-    expect_no_error(RunCoxPlots(df, time1, time2, event, names, term_n, tform, keep_constant, a_n, modelform, control, plot_options))
+    expect_no_error(ep <- plot(e, df, plot_options)$`kaplin-meier`)
+    expect_equal(ep$n_t[3], 0.7142857, tolerance = 1e-4)
   }
 })
